@@ -117,22 +117,17 @@ class Inventory:
                 "id": "nosub",
                 "display_name": "Baseline no subsidence",
                 "description": "Baseline condition; no subsidence",
-                "filename": "",
-                "scenarios": [
-                    {"id": "historical", "years": [1980]},
-                    {"id": "rcp4p5", "years": [2030, 2050, 2080]},
-                    {"id": "rcp8p5", "years": [2030, 2050, 2080]},
-                ],
+                "filename": "inuncoast_{scenario}_nosub_{year}_0",
+                "scenarios": [{"id": "historical", "years": [1980]}],
             },
             {
                 "event_type": "CoastalInundation",
                 "path": "coastal_inundation/wri/v2",
-                "id": "nosub_95",
+                "id": "nosub/95",
                 "display_name": "95% no subsidence",
-                "description": "No subsidence; 95th percentile sea rise",
-                "filename": "",
+                "description": "No subsidence; 95th percentile sea level rise",
+                "filename": "inuncoast_{scenario}_nosub_{year}_0",
                 "scenarios": [
-                    {"id": "historical", "years": [1980]},
                     {"id": "rcp4p5", "years": [2030, 2050, 2080]},
                     {"id": "rcp8p5", "years": [2030, 2050, 2080]},
                 ],
@@ -140,12 +135,11 @@ class Inventory:
             {
                 "event_type": "CoastalInundation",
                 "path": "coastal_inundation/wri/v2",
-                "id": "nosub_05",
+                "id": "nosub/5",
                 "display_name": "5% no subsidence",
-                "description": "No subsidence; 5th percentile sea rise",
-                "filename": "",
+                "description": "No subsidence; 5th percentile sea level rise",
+                "filename": "inuncoast_{scenario}_nosub_{year}_0_perc_05",
                 "scenarios": [
-                    {"id": "historical", "years": [1980]},
                     {"id": "rcp4p5", "years": [2030, 2050, 2080]},
                     {"id": "rcp8p5", "years": [2030, 2050, 2080]},
                 ],
@@ -153,12 +147,11 @@ class Inventory:
             {
                 "event_type": "CoastalInundation",
                 "path": "coastal_inundation/wri/v2",
-                "id": "nosub_50",
+                "id": "nosub/50",
                 "display_name": "50% no subsidence",
-                "description": "No subsidence; 50th percentile sea rise",
-                "filename": "",
+                "description": "No subsidence; 50th percentile sea level rise",
+                "filename": "inuncoast_{scenario}_nosub_{year}_0_perc_50",
                 "scenarios": [
-                    {"id": "historical", "years": [1980]},
                     {"id": "rcp4p5", "years": [2030, 2050, 2080]},
                     {"id": "rcp8p5", "years": [2030, 2050, 2080]},
                 ],
@@ -169,22 +162,17 @@ class Inventory:
                 "id": "wtsub",
                 "display_name": "Baseline with subsidence",
                 "description": "Baseline condition; with subsidence",
-                "filename": "",
-                "scenarios": [
-                    {"id": "historical", "years": [1980]},
-                    {"id": "rcp4p5", "years": [2030, 2050, 2080]},
-                    {"id": "rcp8p5", "years": [2030, 2050, 2080]},
-                ],
+                "filename": "inuncoast_{scenario}_wtsub_{year}_0",
+                "scenarios": [{"id": "historical", "years": [1980]}],
             },
             {
                 "event_type": "CoastalInundation",
                 "path": "coastal_inundation/wri/v2",
-                "id": "wtsub_95",
+                "id": "wtsub/95",
                 "display_name": "95% with subsidence",
-                "description": "With subsidence; 95th percentile sea rise",
-                "filename": "",
+                "description": "With subsidence; 95th percentile sea level rise",
+                "filename": "inuncoast_{scenario}_wtsub_{year}_0",
                 "scenarios": [
-                    {"id": "historical", "years": [1980]},
                     {"id": "rcp4p5", "years": [2030, 2050, 2080]},
                     {"id": "rcp8p5", "years": [2030, 2050, 2080]},
                 ],
@@ -192,12 +180,11 @@ class Inventory:
             {
                 "event_type": "CoastalInundation",
                 "path": "coastal_inundation/wri/v2",
-                "id": "wtsub_05",
+                "id": "wtsub/5",
                 "display_name": "5% with subsidence",
-                "description": "With subsidence; 5th percentile sea rise",
-                "filename": "",
+                "description": "With subsidence; 5th percentile sea level rise",
+                "filename": "inuncoast_{scenario}_wtsub_{year}_0_perc_05",
                 "scenarios": [
-                    {"id": "historical", "years": [1980]},
                     {"id": "rcp4p5", "years": [2030, 2050, 2080]},
                     {"id": "rcp8p5", "years": [2030, 2050, 2080]},
                 ],
@@ -205,12 +192,11 @@ class Inventory:
             {
                 "event_type": "CoastalInundation",
                 "path": "coastal_inundation/wri/v2",
-                "id": "wtsub_50",
+                "id": "wtsub/50",
                 "display_name": "50% with subsidence",
-                "description": "With subsidence; 50th percentile sea rise",
-                "filename": "",
+                "description": "With subsidence; 50th percentile sea level rise",
+                "filename": "inuncoast_{scenario}_wtsub_{year}_0_perc_50",
                 "scenarios": [
-                    {"id": "historical", "years": [1980]},
                     {"id": "rcp4p5", "years": [2030, 2050, 2080]},
                     {"id": "rcp8p5", "years": [2030, 2050, 2080]},
                 ],
